@@ -246,3 +246,7 @@ def get_objects(model_name):
     p = m.parts
 
     return m, a, p
+
+
+def get_kwargs_string(**kwargs):
+    return " ".join(["{}:{}".format(key, value) for key, value in kwargs.items()])
